@@ -1,4 +1,6 @@
-import requests
+# from covidactnow import covid
+
+import requests 
 
 # As CovidActNow's API is a REST API, queries are stored as URLs.
 
@@ -11,48 +13,62 @@ class User:
 
     def infRate(self, state):
         # Infection Rate
-        if True:
+        try:
             return float(requests.get(self.queryUrl(state)).json()['metrics']['infectionRate'])
-        else:
-           return "NaN"
+        except TypeError:
+            return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
         
     def posRate(self, state):    
         # Positive Rate
-        if True:
+        try:
             return round(100*float(requests.get(self.queryUrl(state)).json()['metrics']['testPositivityRatio']), 2)
-        else:
+        except TypeError:
             return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
     
     def vaxRate(self, state):
         # Vax Rate
         try:
             return round(100*float(requests.get(self.queryUrl(state)).json()['metrics']['vaccinationsCompletedRatio']), 2)
-        except:
+        except TypeError:
             return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
     
     def freeBedPercentage(self, state):
         # Free Bed Percentage
         try:
             return round(100*float(requests.get(self.queryUrl(state)).json()['actuals']['hospitalBeds']['currentUsageTotal'])/\
                 float(requests.get(self.queryUrl(state)).json()['actuals']['hospitalBeds']['capacity']), 2)
-        except:
+        except TypeError:
             return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
         
     def newCases(self, state):
         try:
             return int(requests.get(self.queryUrl(state)).json()['actuals']['newCases'])
-        except:
+        except TypeError:
             return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
 
     def newDeaths(self, state):
         try:
             return int(requests.get(self.queryUrl(state)).json()['actuals']['newDeaths'])
-        except:
+        except TypeError:
             return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
         
     def covidBedPercentage(self, state):
         try:
             return round(100*float(requests.get(self.queryUrl(state)).json()['actuals']['hospitalBeds']['currentUsageCovid'])/\
                 float(requests.get(self.queryUrl(state)).json()['actuals']['hospitalBeds']['capacity']), 2)
-        except:
-            return "NaN"
\ No newline at end of file
+        except TypeError:
+            return "NaN"
+        except Exception as e:
+            print(f"An error occured in data collection: {e}")
\ No newline at end of file
